@@ -17,12 +17,13 @@ from bs4 import BeautifulSoup
 from selenium.webdriver.common.by import By
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
+from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 
 
 class SpiderOp(object):
     def __init__(self, executable_path='chromedriver', headless=None,
                  ip=None, wait_time=1, try_num=2, time_to_wait_load=None,
-                 downLoad=False, downLoadPath='./', js_str=None):
+                 downLoad=False, downLoadPath='./', js_str=None, options=None):
         """
         :param executable_path:
         :param headless:
@@ -34,25 +35,36 @@ class SpiderOp(object):
         :param downLoadPath:
         :param js_str: with open('/Users/kingname/test_pyppeteer/stealth.min.js') as f: js = f.read()
         """
-        opt = webdriver.ChromeOptions()  # 创建Chrome参数对象
-        # opt.headless = headless  # 把True Chrome设置成可视化无界面模式，windows/Linux 皆可
+        if options:
+            self.opt = options
+        else:
+            self.opt = webdriver.ChromeOptions()  # 创建Chrome参数对象
+        # self.opt.headless = headless  # 把True Chrome设置成可视化无界面模式，windows/Linux 皆可
         if headless:
-            opt.add_argument('--no-sandbox')  # 解决DevToolsActivePort文件不存在的报错
-            opt.add_argument('window-size=1920x1080')  # 指定浏览器分辨率
-            opt.add_argument('--disable-gpu')  # 谷歌文档提到需要加上这个属性来规避bug
-            opt.add_argument('log-level=3')
-            opt.add_experimental_option('excludeSwitches', ['enable-automation'])
-            opt.add_argument('--headless')
-            opt.add_argument(
+            self.opt.add_argument('--no-sandbox')  # 解决DevToolsActivePort文件不存在的报错
+            self.opt.add_argument('window-size=1920x1080')  # 指定浏览器分辨率
+            self.opt.add_argument('--disable-gpu')  # 谷歌文档提到需要加上这个属性来规避bug
+            self.opt.add_argument('log-level=3')
+            self.opt.add_experimental_option('excludeSwitches', ['enable-automation'])
+            self.opt.add_argument('--headless')
+            self.opt.add_argument(
                 "--user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.130 Safari/537.36")
-            opt.add_argument("--disable-dev-shm-usage")
-            opt.add_argument("lang=zh_CN.UTF-8")
+            self.opt.add_argument("--disable-dev-shm-usage")
+            self.opt.add_argument("lang=zh_CN.UTF-8")
 
         if downLoad:
             prefs = {'profile.default_content_settings.popups': 0, 'download.default_directory': downLoadPath}
-            opt.add_experimental_option('prefs', prefs)
+            self.opt.add_experimental_option('prefs', prefs)
+
+
+        if executable_path.startswith('http'):
+            # command_executor="http://127.0.0.1:4444/wd/hub" docker selenium环境http地址
+            self.driver = webdriver.Remote(
+                command_executor=executable_path, desired_capabilities=DesiredCapabilities.CHROME,
+                                           options=self.opt)  # 没有把Chromedriver放到python安装路径
+        else:
+            self.driver = webdriver.Chrome(executable_path=executable_path, options=self.opt)  # 没有把Chromedriver放到python安装路径
 
-        self.driver = webdriver.Chrome(executable_path=executable_path, options=opt)  # 没有把Chromedriver放到python安装路径
         if time_to_wait_load:
             self.driver.set_page_load_timeout(time_to_wait_load)
             self.driver.set_script_timeout(time_to_wait_load)
